

### <a name="manual"></a> Anchor block

Inserts table of content calculated from chapter blocks.

| Key       |      Description      | Default |
|:----------|:--------------------- |:----- |
| type      |  anchor                 |  
| name      |  name of the anchor used for referencing      |  
| label     |  label rendered for this anchor     |  
| style     |  stylename used for this anchor     |  BodyText |
| visible   |  Defines if anchor is visible or hidden    |  True |
| keeptogether   |  Defines if is spitted or not (flowable), this is useful when anchor is used in tables   |  True |



Example:
```YAML
- type     : toc
```

Back to [Documentation](../../../README.md#block_structure)
